==> haskell-hjsmin-0.2.0.2-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.2.0.2
id: hjsmin-0.2.0.2-EavLvoT0jfd25LMHcIIpPL
key: hjsmin-0.2.0.2-EavLvoT0jfd25LMHcIIpPL
license: BSD-3-Clause
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
author: Alan Zimmerman <alan.zimm@gmail.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
abi: c318768195224014da4b8a0c2b158e43
exposed: True
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
import-dirs: /usr/lib/ghc-8.6.4/site-local/hjsmin-0.2.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hjsmin-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hjsmin-0.2.0.2
hs-libraries: HShjsmin-0.2.0.2-EavLvoT0jfd25LMHcIIpPL
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    language-javascript-0.6.0.11-EORWeExf4JA8bwgXEwH8U1 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.0.2-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.2.0.2
id: hjsmin-0.2.0.2-LNLHY2IUcpaHFcPeNuDW4
key: hjsmin-0.2.0.2-LNLHY2IUcpaHFcPeNuDW4
license: BSD-3-Clause
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
author: Alan Zimmerman <alan.zimm@gmail.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
abi: 164ea6f6f60f5a0b975f89976f5384b1
exposed: True
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
import-dirs: /usr/lib/ghc-8.6.4/site-local/hjsmin-0.2.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hjsmin-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hjsmin-0.2.0.2
hs-libraries: HShjsmin-0.2.0.2-LNLHY2IUcpaHFcPeNuDW4
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    language-javascript-0.6.0.11-EORWeExf4JA8bwgXEwH8U1 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
